%bcond_with sane
%bcond_with test

Summary:       Color daemon
Name:          colord
Version:       1.4.6
Release:       3%{?dist}
License:       GPLv2+ and LGPLv2+
URL:           https://www.freedesktop.org/software/colord/
Source0:       https://www.freedesktop.org/software/colord/releases/%{name}-%{version}.tar.xz

BuildRequires: dbus-devel glib2-devel systemd-devel lcms2-devel libgudev1-devel
BuildRequires: polkit-devel sqlite-devel gobject-introspection-devel libgusb-devel
BuildRequires: libxslt docbook5-style-xsl gettext vala gtk-doc color-filesystem meson systemd

%if %{with sane}
BuildRequires: sane-backends-devel dbus-devel
%endif

Requires:      color-filesystem
Requires(pre): shadow-utils
Requires:      colord-libs = %{version}-%{release}
%{?systemd_requires}

Provides:      extra-profiles = %{version}-%{release}
Provides:      shared-color-profiles
Provides:      shared-color-profiles-extra

%description
colord is a low level system activated daemon that maps color devices
to color profiles in the system context. Besides, this package provides
more color profiles for color management that are less commonly used,
which may be useful for CMYK soft-proofing or for extra device support.

%package       libs
Summary:       Color daemon library

%description   libs
This package provides libs for %{name}.

%package       devel
Summary:       Development package for %{name}
Requires:      %{name} = %{version}-%{release}
Requires:      %{name}-libs = %{version}-%{release}

%description   devel
This packages provides files for development with %{name}.

%if %{with test}
%package       tests
Summary:       Data files for installed tests

%description   tests
This package provides data files for installed tests.
%endif

%prep
%autosetup -n %{name}-%{version} -p1

%build
ulimit -Sv 2000000

%meson \
    -Dvapi=true              \
    -Dprint_profiles=false   \
    -Dbash_completion=false  \
    -Dargyllcms_sensor=false \
%if %{without test}
    -Dinstalled_tests=false  \
%endif
%if %{with sane}
    -Dsane=true              \
%endif
    -Ddaemon_user=colord

%meson_build

%install
%meson_install

touch %{buildroot}%{_localstatedir}/lib/colord/mapping.db
touch %{buildroot}%{_localstatedir}/lib/colord/storage.db

# do not support html doc
rm -rf %{buildroot}%{_datadir}/gtk-doc/html/colord/*

%find_lang %{name}

%pre
getent group colord >/dev/null || groupadd -r colord
getent passwd colord >/dev/null || \
    useradd -r -g colord -d /var/lib/colord -s /sbin/nologin \
    -c "User for colord" colord
exit 0

%post
%systemd_post colord.service

%preun
%systemd_preun colord.service

%postun
%systemd_postun colord.service

%files -f %{name}.lang
%license COPYING
%doc README.md AUTHORS NEWS
%{_libexecdir}/colord
%attr(755,colord,colord) %dir %{_localstatedir}/lib/colord
%attr(755,colord,colord) %dir %{_localstatedir}/lib/colord/icc
%{_bindir}/*
%{_datadir}/glib-2.0/schemas/org.freedesktop.ColorHelper.gschema.xml
%{_datadir}/dbus-1/system.d/org.freedesktop.ColorManager.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorManager*.xml
%{_datadir}/polkit-1/actions/org.freedesktop.color.policy
%{_datadir}/dbus-1/system-services/org.freedesktop.ColorManager.service
%{_datadir}/colord
/usr/lib/udev/rules.d/*.rules
/usr/lib/tmpfiles.d/colord.conf
%{_libdir}/colord-sensors
%{_libdir}/colord-plugins
%ghost %attr(-,colord,colord) %{_localstatedir}/lib/colord/*.db
%{_unitdir}/colord.service
%{_libexecdir}/colord-session
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorHelper.xml
%{_datadir}/dbus-1/services/org.freedesktop.ColorHelper.service
%{_userunitdir}/colord-session.service

%dir %{_icccolordir}/colord
%{_icccolordir}/colord/*.icc
%{_datadir}/man/man1/*.1.gz

%if %{with sane}
%{_libexecdir}/colord-sane
%endif

%files libs
%license COPYING
%{_libdir}/libcolord.so.2*
%{_libdir}/libcolordprivate.so.2*
%{_libdir}/libcolorhug.so.2*
%{_libdir}/girepository-1.0/*.typelib

%files devel
%{_includedir}/colord-1
%{_libdir}/libcolord.so
%{_libdir}/libcolordprivate.so
%{_libdir}/libcolorhug.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/colord.vapi
%{_datadir}/vala/vapi/colord.deps

%if %{with test}
%files tests
%dir %{_libexecdir}/installed-tests/colord
%{_libexecdir}/installed-tests/colord/*
%dir %{_datadir}/installed-tests/colord
%{_datadir}/installed-tests/colord/*
%endif

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.6-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.6-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Sep 13 2022 Shuo Wang <abushwang@tencent.com> - 1.4.6-1
- initial build

